# py-semantic-taxonomy

[![PyPI](https://img.shields.io/pypi/v/py-semantic-taxonomy.svg)][pypi status]
[![Status](https://img.shields.io/pypi/status/py-semantic-taxonomy.svg)][pypi status]
[![Python Version](https://img.shields.io/pypi/pyversions/py-semantic-taxonomy)][pypi status]
[![License](https://img.shields.io/pypi/l/py-semantic-taxonomy)][license]
[![Tests](https://github.com/cauldron/py-semantic-taxonomy/actions/workflows/python-test.yml/badge.svg)][tests]

[pypi status]: https://pypi.org/project/py-semantic-taxonomy/
[tests]: https://github.com/cauldron/py-semantic-taxonomy/actions?workflow=Tests

## A Knowledge Organization System for Sustainability Assessment

PyST is opinionated server software for creating, maintaining, and publishing [SKOS](https://www.w3.org/TR/skos-reference/)/[XKOS](https://rdf-vocabulary.ddialliance.org/xkos.html) taxonomies.

* [General documentation](https://docs.pyst.dev)
* [API documentation](https://docs.pytest.dev/api/)
* [Example notebook](https://github.com/cauldron/py-semantic-taxonomy/blob/main/examples/PyST%20basic%20demo.ipynb)

## Contributing

Contributions are very welcome. Please be nice.

## License

Distributed under the terms of the [MIT license][License],
_py_semantic_taxonomy_ is free and open source software.

## Issues

If you encounter any problems,
please [file an issue][Issue Tracker] along with a detailed description.


<!-- github-only -->

[License]: https://github.com/cauldron/py-semantic-taxonomy/blob/main/LICENSE
[Issue Tracker]: https://github.com/cauldron/py-semantic-taxonomy/issues
